@@ -2,7 +2,7 @@ package Minilla;
 use strict;
 use warnings;
 use 5.008005;
-use version; our $VERSION = version->declare("v0.4.2");
+use version; our $VERSION = version->declare("v0.4.3");
 
 our $DEBUG;
 our $AUTO_INSTALL;
@@ -165,6 +165,24 @@ Specify a custom Module::Build subclass.
     [build]
     build_class = builder::MyBuilder
 
+=item FileGatherer.exclude_match
+
+    [FileGatherer]
+    exclude_match=['^author_tools/.*']
+
+Nothing by default. To exclude certain files from being gathered into dist, use the
+C<exclude_match> option. Files matching the patterns are not gathered.
+
+=item FileGatherer.include_dotfiles
+
+    [FileGatherer]
+    include_dotfiles=false
+
+By default, files will not be included in dist if they begin with a dot. This goes
+both for files and for directories.
+
+In almost all cases, the default value (false) is correct.
+
 =back
 
 =head1 FAQ
