@@ -35,16 +35,9 @@ sub generate {
 __DATA__
 
 @@ cpanfile
-on 'configure' => sub {
-};
-
-on 'build' => sub {
-};
+requires 'perl', '5.008001';
 
 on 'test' => sub {
     requires 'Test::More', '0.98';
 };
 
-on 'develop' => sub {
-};
-
